@@ -18,15 +18,18 @@
 
 #include "../config-parley.h"
 
-#include "vocabulary/vocabularymodel.h"
-#include "vocabulary/vocabularyview.h"
-#include "vocabulary/vocabularyfilter.h"
-#include "vocabulary/containerview.h"
-#include "vocabulary/lessonview.h"
-#include "vocabulary/wordtypeview.h"
-#include "vocabulary/containermodel.h"
-#include "vocabulary/lessonmodel.h"
-#include "vocabulary/wordtypemodel.h"
+// Qt models on top of the KEduVocDocument
+#include "containermodel.h"
+#include "lessonmodel.h"
+#include "vocabularymodel.h"
+#include "vocabularyfilter.h"
+#include "wordclassmodel.h"
+
+// Views
+#include "vocabularyview.h"
+#include "containerview.h"
+#include "lessonview.h"
+#include "wordtypeview.h"
 
 #include "multiplechoicewidget.h"
 #include "comparisonwidget.h"
@@ -145,7 +148,7 @@ void EditorWindow::updateDocument(KEduVocDocument *doc)
 
 void EditorWindow::initDockWidgets()
 {
-// Lesson dock
+    // Lesson dockwidget
     QDockWidget *lessonDockWidget = new QDockWidget(i18n("Lessons"), this);
     lessonDockWidget->setObjectName("LessonDock");
     m_lessonView = new LessonView(this);
@@ -170,7 +173,7 @@ void EditorWindow::initDockWidgets()
             m_lessonView, SLOT(setTranslation(KEduVocExpression*, int)));
 
 
-// Word types dock
+    // Word classes dock widget
     QDockWidget* wordTypeDockWidget = new QDockWidget(i18n("Word Types"), this);
     wordTypeDockWidget->setObjectName("WordTypeDock");
     m_wordTypeView = new WordTypeView(this);
@@ -178,7 +181,7 @@ void EditorWindow::initDockWidgets()
     addDockWidget(Qt::LeftDockWidgetArea, wordTypeDockWidget);
     m_dockWidgets.append(wordTypeDockWidget);
 
-    m_wordTypeModel = new WordTypeModel(this);
+    m_wordTypeModel = new WordClassModel(this);
     wordTypeDockWidget->setVisible(false);
     actionCollection()->addAction("show_wordtype_dock", wordTypeDockWidget->toggleViewAction());
 
