@@ -21,9 +21,9 @@
 #include "version.h"
 #include "prefs.h"
 
-#include "vocabulary/vocabularyview.h"
+#include "vocabularyview.h"
 #include "settings/documentproperties.h"
-#include "welcomescreen/welcomescreen.h"
+#include "dashboard/dashboard.h"
 
 #include <keduvoclesson.h>
 #include <keduvocleitnerbox.h>
@@ -45,7 +45,7 @@
 #include <QtGui/QPrintDialog>
 
 #ifdef HAVE_LIBXSLT
-#include "export/exportdialog.h"
+#include "exportdialog.h"
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 #include <libxslt/xslt.h>
@@ -549,7 +549,7 @@ void ParleyDocument::slotGHNS()
         }
     }
 
-    // to enable the display in the welcome screen
+    // to enable the display in the dashboard
     Prefs::self()->writeConfig();
     m_parleyApp->updateRecentFilesModel();
     if (numberInstalled > 1) {
