@@ -20,10 +20,11 @@
 
 using namespace Practice;
 
-ComparisonBackendMode::ComparisonBackendMode(const PracticeOptions& practiceOptions,
-        AbstractFrontend* frontend, QObject* parent, Practice::TestEntryManager* testEntryManager, KEduVocDocument* doc)
-    : AbstractBackendMode(practiceOptions, frontend, parent)
-    , m_testEntryManager(testEntryManager)
+ComparisonBackendMode::ComparisonBackendMode(AbstractFrontend* frontend, QObject* parent,
+                                             Practice::SessionManagerBase* sessionManager,
+                                             KEduVocDocument* doc)
+    : AbstractBackendMode(frontend, parent)
+    , m_sessionManager(sessionManager)
     , m_doc(doc)
 {
 }
@@ -33,8 +34,8 @@ bool ComparisonBackendMode::setTestEntry(TestEntry* current)
     m_current = current;
     m_lastAnswers.clear();
 
-    int languageTo = m_practiceOptions.languageTo();
-    int languageFrom = m_practiceOptions.languageFrom();
+    int languageTo = current->languageTo();
+    int languageFrom = current->languageFrom();
 
     m_frontend->setQuestion(m_current->entry()->translation(languageFrom)->text());
     QStringList answers;
@@ -43,10 +44,10 @@ bool ComparisonBackendMode::setTestEntry(TestEntry* current)
     answers.append(m_current->entry()->translation(languageTo)->superlative());
     m_frontend->setSolution(answers);
 
-    m_frontend->setQuestionSound(m_current->entry()->translation(m_practiceOptions.languageFrom())->soundUrl());
-    m_frontend->setSolutionSound(m_current->entry()->translation(m_practiceOptions.languageTo())->soundUrl());
-    m_frontend->setQuestionPronunciation(m_current->entry()->translation(m_practiceOptions.languageFrom())->pronunciation());
-    m_frontend->setSolutionPronunciation(m_current->entry()->translation(m_practiceOptions.languageTo())->pronunciation());
+    m_frontend->setQuestionSound(m_current->entry()->translation(m_current->languageFrom())->soundUrl());
+    m_frontend->setSolutionSound(m_current->entry()->translation(m_current->languageTo())->soundUrl());
+    m_frontend->setQuestionPronunciation(m_current->entry()->translation(m_current->languageFrom())->pronunciation());
+    m_frontend->setSolutionPronunciation(m_current->entry()->translation(m_current->languageTo())->pronunciation());
     m_frontend->setResultState(AbstractFrontend::QuestionState);
     m_frontend->showQuestion();
     return true;
@@ -61,9 +62,9 @@ void ComparisonBackendMode::checkAnswer()
         return;
     }
 
-    bool absoluteCorrect = answers.at(0) == m_current->entry()->translation(Prefs::solutionLanguage())->text();
-    bool comparativeCorrect = answers.at(1) == m_current->entry()->translation(Prefs::solutionLanguage())->comparative();
-    bool superlativeCorrect = answers.at(2) == m_current->entry()->translation(Prefs::solutionLanguage())->superlative();
+    bool absoluteCorrect = answers.at(0) == m_current->entry()->translation(m_current->languageTo())->text();
+    bool comparativeCorrect = answers.at(1) == m_current->entry()->translation(m_current->languageTo())->comparative();
+    bool superlativeCorrect = answers.at(2) == m_current->entry()->translation(m_current->languageTo())->superlative();
 
     if (absoluteCorrect && comparativeCorrect && superlativeCorrect) {
         m_frontend->setFeedback(i18n("All comparison forms were right."));
@@ -98,39 +99,25 @@ void ComparisonBackendMode::updateGrades()
 {
     QStringList answers = m_frontend->userInput().toStringList();
 
-    bool absoluteCorrect = answers.at(0) == m_current->entry()->translation(Prefs::solutionLanguage())->text();
-    bool comparativeCorrect = answers.at(1) == m_current->entry()->translation(Prefs::solutionLanguage())->comparative();
-    bool superlativeCorrect = answers.at(2) == m_current->entry()->translation(Prefs::solutionLanguage())->superlative();
+    bool absoluteCorrect = answers.at(0) == m_current->entry()->translation(m_current->languageTo())->text();
+    bool comparativeCorrect = answers.at(1) == m_current->entry()->translation(m_current->languageTo())->comparative();
+    bool superlativeCorrect = answers.at(2) == m_current->entry()->translation(m_current->languageTo())->superlative();
 
     // TODO way too much duplicated code here
 
-    KEduVocTranslation* translation = m_current->entry()->translation(m_practiceOptions.languageTo());
+    KEduVocTranslation* translation = m_current->entry()->translation(m_current->languageTo());
 
     translation->incPracticeCount();
     translation->setPracticeDate(QDateTime::currentDateTime());
 
-    if (absoluteCorrect) {
-        if (m_current->statisticBadCount() == 0) {
-            translation->incGrade();
-        }
-    } else {
-        translation->setGrade(KV_LEV1_GRADE);
-        translation->incBadCount();
-    }
+    updateGrade(*translation, absoluteCorrect, m_current->statisticBadCount() == 0);
 
     KEduVocText comp = translation->comparativeForm();
 
     comp.incPracticeCount();
     comp.setPracticeDate(QDateTime::currentDateTime());
 
-    if (comparativeCorrect) {
-        if (m_current->statisticBadCount() == 0) {
-            comp.incGrade();
-        }
-    } else {
-        comp.setGrade(KV_LEV1_GRADE);
-        comp.incBadCount();
-    }
+    updateGrade(comp, comparativeCorrect, m_current->statisticBadCount() == 0);
     translation->setComparativeForm(comp);
 
     KEduVocText super = translation->superlativeForm();
@@ -138,14 +125,7 @@ void ComparisonBackendMode::updateGrades()
     super.incPracticeCount();
     super.setPracticeDate(QDateTime::currentDateTime());
 
-    if (superlativeCorrect) {
-        if (m_current->statisticBadCount() == 0) {
-            super.incGrade();
-        }
-    } else {
-        super.setGrade(KV_LEV1_GRADE);
-        super.incBadCount();
-    }
+    updateGrade(super, superlativeCorrect, m_current->statisticBadCount() == 0);
     translation->setSuperlativeForm(super);
 }
 
