@@ -24,7 +24,8 @@ class ExampleSentenceBackendMode : public WrittenBackendMode
 {
     Q_OBJECT
 public:
-    ExampleSentenceBackendMode(const Practice::PracticeOptions& practiceOptions, Practice::AbstractFrontend* frontend, QObject* parent, Practice::TestEntryManager* testEntryManager, KEduVocDocument* doc);
+    ExampleSentenceBackendMode(Practice::AbstractFrontend* frontend, QObject* parent,
+                               Practice::SessionManagerBase* sessionManager, KEduVocDocument* doc);
 
     virtual bool setTestEntry(TestEntry* current);
 };
